import { CosmWasmClient } from "@cosmjs/cosmwasm-stargate";
import { BankExtension, IbcExtension, QueryClient } from "@cosmjs/stargate";
import { Chain, ChainsConfig, Network, PlatformContext, SignedTx, TxHash } from "@wormhole-foundation/connect-sdk";
import { CosmwasmChain } from "./chain";
import { IbcChannels } from "./constants";
import { CosmwasmChains, CosmwasmPlatformType } from "./types";
import { Balances, TokenId } from "@wormhole-foundation/connect-sdk";
import { AnyCosmwasmAddress } from "./types";
/**
 * @category Cosmwasm
 */
export declare class CosmwasmPlatform<N extends Network> extends PlatformContext<N, CosmwasmPlatformType> {
    static _platform: CosmwasmPlatformType;
    constructor(network: N, _config?: ChainsConfig<N, CosmwasmPlatformType>);
    getRpc<C extends CosmwasmChains>(chain: C): Promise<CosmWasmClient>;
    getChain<C extends CosmwasmChains>(chain: C, rpc?: CosmWasmClient): CosmwasmChain<N, C>;
    static getQueryClient: (rpc: CosmWasmClient) => QueryClient & BankExtension & IbcExtension;
    static getIbcChannels<N extends Network, C extends CosmwasmChains>(network: N, chain: C): IbcChannels | null;
    static nativeTokenId<C extends CosmwasmChains>(network: Network, chain: C): TokenId<C>;
    static isSupportedChain(chain: Chain): boolean;
    static isNativeTokenId<N extends Network, C extends CosmwasmChains>(network: N, chain: C, tokenId: TokenId): boolean;
    static getDecimals<C extends CosmwasmChains>(chain: C, rpc: CosmWasmClient, token: AnyCosmwasmAddress | "native"): Promise<bigint>;
    static getBalance<C extends CosmwasmChains>(chain: C, rpc: CosmWasmClient, walletAddress: string, token: AnyCosmwasmAddress | "native"): Promise<bigint | null>;
    static getBalances<C extends CosmwasmChains>(chain: C, rpc: CosmWasmClient, walletAddress: string, tokens: (AnyCosmwasmAddress | "native")[]): Promise<Balances>;
    static getNativeDenom<N extends Network, C extends CosmwasmChains>(network: N, chain: C): string;
    static sendWait(chain: Chain, rpc: CosmWasmClient, stxns: SignedTx[]): Promise<TxHash[]>;
    static getLatestBlock(rpc: CosmWasmClient): Promise<number>;
    static getLatestFinalizedBlock(rpc: CosmWasmClient): Promise<number>;
    static chainFromChainId(chainMoniker: string): [Network, CosmwasmChains];
    static chainFromRpc(rpc: CosmWasmClient): Promise<[Network, CosmwasmChains]>;
    static getCounterpartyChannel(sourceChannel: string, rpc: CosmWasmClient): Promise<string | null>;
}
//# sourceMappingURL=platform.d.ts.map